diff --git a/README.md b/README.md
index 1259055..530d4e1 100644
--- a/README.md
+++ b/README.md
@@ -4,8 +4,8 @@ Push API resources Open API documentation
This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:
-- API version: 1.0
-- SDK version: 0.0.2
+- API version: 0.4.4-alpha.4
+- SDK version: 0.0.3
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen
@@ -107,20 +107,23 @@ namespace Example
{
Configuration config = new Configuration();
- config.BasePath = "http://localhost:8080/q/openapi";
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
// create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
HttpClient httpClient = new HttpClient();
HttpClientHandler httpClientHandler = new HttpClientHandler();
var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
- var payloadModel = new PayloadModel?(); // PayloadModel? | (optional)
try
{
- apiInstance.RootPost(payloadModel);
+ apiInstance.DataDelete();
}
catch (ApiException e)
{
- Debug.Print("Exception when calling DefaultApi.RootPost: " + e.Message );
+ Debug.Print("Exception when calling DefaultApi.DataDelete: " + e.Message );
Debug.Print("Status Code: "+ e.ErrorCode);
Debug.Print(e.StackTrace);
}
@@ -133,19 +136,25 @@ namespace Example
## Documentation for API Endpoints
-All URIs are relative to *http://localhost:8080/q/openapi*
+All URIs are relative to *https://push.databox.com*
Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
-*DefaultApi* | [**RootPost**](docs/DefaultApi.md#rootpost) | **POST** / |
+*DefaultApi* | [**DataDelete**](docs/DefaultApi.md#datadelete) | **DELETE** /data |
+*DefaultApi* | [**DataMetricKeyDelete**](docs/DefaultApi.md#datametrickeydelete) | **DELETE** /data/{metricKey} |
+*DefaultApi* | [**DataPost**](docs/DefaultApi.md#datapost) | **POST** /data |
+*DefaultApi* | [**MetrickeysGet**](docs/DefaultApi.md#metrickeysget) | **GET** /metrickeys |
+*DefaultApi* | [**MetrickeysPost**](docs/DefaultApi.md#metrickeyspost) | **POST** /metrickeys |
+*DefaultApi* | [**PingGet**](docs/DefaultApi.md#pingget) | **GET** /ping |
## Documentation for Models
- [Model.ApiResponse](docs/ApiResponse.md)
- - [Model.PayloadDataModel](docs/PayloadDataModel.md)
- - [Model.PayloadModel](docs/PayloadModel.md)
+ - [Model.PushData](docs/PushData.md)
+ - [Model.PushDataAttribute](docs/PushDataAttribute.md)
+ - [Model.State](docs/State.md)
diff --git a/src/docs/PayloadModel.md b/docs/ApiResponse.md
similarity index 70%
rename from src/docs/PayloadModel.md
rename to docs/ApiResponse.md
index 35487d8..61a0934 100644
--- a/src/docs/PayloadModel.md
+++ b/docs/ApiResponse.md
@@ -1,10 +1,11 @@
-# Databox.Model.PayloadModel
+# Databox.Model.ApiResponse
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
-**Data** | [**List<PayloadDataModel>**](PayloadDataModel.md) | | [optional]
+**Status** | **string** | | [optional]
+**Message** | **string** | | [optional]
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
diff --git a/docs/DefaultApi.md b/docs/DefaultApi.md
new file mode 100644
index 0000000..eee4b89
--- /dev/null
+++ b/docs/DefaultApi.md
@@ -0,0 +1,544 @@
+# Databox.Api.DefaultApi
+
+All URIs are relative to *https://push.databox.com*
+
+| Method | HTTP request | Description |
+|--------|--------------|-------------|
+| [**DataDelete**](DefaultApi.md#datadelete) | **DELETE** /data | |
+| [**DataMetricKeyDelete**](DefaultApi.md#datametrickeydelete) | **DELETE** /data/{metricKey} | |
+| [**DataPost**](DefaultApi.md#datapost) | **POST** /data | |
+| [**MetrickeysGet**](DefaultApi.md#metrickeysget) | **GET** /metrickeys | |
+| [**MetrickeysPost**](DefaultApi.md#metrickeyspost) | **POST** /metrickeys | |
+| [**PingGet**](DefaultApi.md#pingget) | **GET** /ping | |
+
+
+# **DataDelete**
+> void DataDelete ()
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class DataDeleteExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+
+ try
+ {
+ apiInstance.DataDelete();
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataDelete: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataDeleteWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataDeleteWithHttpInfo();
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataDeleteWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+This endpoint does not need any parameter.
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **DataMetricKeyDelete**
+> void DataMetricKeyDelete (string metricKey)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class DataMetricKeyDeleteExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var metricKey = "metricKey_example"; // string |
+
+ try
+ {
+ apiInstance.DataMetricKeyDelete(metricKey);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataMetricKeyDelete: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataMetricKeyDeleteWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataMetricKeyDeleteWithHttpInfo(metricKey);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataMetricKeyDeleteWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+
+| Name | Type | Description | Notes |
+|------|------|-------------|-------|
+| **metricKey** | **string** | | |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **DataPost**
+> void DataPost (List? pushData = null)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class DataPostExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var pushData = new List?(); // List? | (optional)
+
+ try
+ {
+ apiInstance.DataPost(pushData);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataPost: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataPostWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataPostWithHttpInfo(pushData);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataPostWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+
+| Name | Type | Description | Notes |
+|------|------|-------------|-------|
+| **pushData** | [**List<PushData>?**](PushData.md) | | [optional] |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: application/json, application/vnd.databox.v2+json
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **MetrickeysGet**
+> void MetrickeysGet ()
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class MetrickeysGetExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+
+ try
+ {
+ apiInstance.MetrickeysGet();
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.MetrickeysGet: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the MetrickeysGetWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.MetrickeysGetWithHttpInfo();
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.MetrickeysGetWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+This endpoint does not need any parameter.
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **MetrickeysPost**
+> void MetrickeysPost (Object? body = null)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class MetrickeysPostExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var body = null; // Object? | (optional)
+
+ try
+ {
+ apiInstance.MetrickeysPost(body);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.MetrickeysPost: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the MetrickeysPostWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.MetrickeysPostWithHttpInfo(body);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.MetrickeysPostWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+
+| Name | Type | Description | Notes |
+|------|------|-------------|-------|
+| **body** | **Object?** | | [optional] |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: application/json, application/vnd.databox.v2+json
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **PingGet**
+> void PingGet ()
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class PingGetExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+
+ try
+ {
+ apiInstance.PingGet();
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.PingGet: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the PingGetWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.PingGetWithHttpInfo();
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.PingGetWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+This endpoint does not need any parameter.
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
diff --git a/docs/PushData.md b/docs/PushData.md
new file mode 100644
index 0000000..82b456d
--- /dev/null
+++ b/docs/PushData.md
@@ -0,0 +1,16 @@
+# Databox.Model.PushData
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+**Attributes** | [**List<PushDataAttribute>**](PushDataAttribute.md) | | [optional]
+**Date** | **string** | | [optional]
+**Key** | **string** | | [optional]
+**PeriodFrom** | **string** | | [optional]
+**PeriodTo** | **string** | | [optional]
+**Unit** | **string** | | [optional]
+**Value** | **float** | | [optional]
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/docs/PushDataAttribute.md b/docs/PushDataAttribute.md
new file mode 100644
index 0000000..2f164c8
--- /dev/null
+++ b/docs/PushDataAttribute.md
@@ -0,0 +1,11 @@
+# Databox.Model.PushDataAttribute
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+**Key** | **string** | | [optional]
+**Value** | **string** | | [optional]
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/docs/State.md b/docs/State.md
new file mode 100644
index 0000000..f6636e1
--- /dev/null
+++ b/docs/State.md
@@ -0,0 +1,9 @@
+# Databox.Model.State
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/src/.openapi-generator/FILES b/src/.openapi-generator/FILES
index 91d2702..dd53dd3 100644
--- a/src/.openapi-generator/FILES
+++ b/src/.openapi-generator/FILES
@@ -5,14 +5,16 @@ api/openapi.yaml
appveyor.yml
docs/ApiResponse.md
docs/DefaultApi.md
-docs/PayloadDataModel.md
-docs/PayloadModel.md
+docs/PushData.md
+docs/PushDataAttribute.md
+docs/State.md
git_push.sh
src/Databox.Test/Api/DefaultApiTests.cs
src/Databox.Test/Databox.Test.csproj
src/Databox.Test/Model/ApiResponseTests.cs
-src/Databox.Test/Model/PayloadDataModelTests.cs
-src/Databox.Test/Model/PayloadModelTests.cs
+src/Databox.Test/Model/PushDataAttributeTests.cs
+src/Databox.Test/Model/PushDataTests.cs
+src/Databox.Test/Model/StateTests.cs
src/Databox/Api/DefaultApi.cs
src/Databox/Client/ApiClient.cs
src/Databox/Client/ApiException.cs
@@ -34,5 +36,6 @@ src/Databox/Client/WebRequestPathBuilder.cs
src/Databox/Databox.csproj
src/Databox/Model/AbstractOpenAPISchema.cs
src/Databox/Model/ApiResponse.cs
-src/Databox/Model/PayloadDataModel.cs
-src/Databox/Model/PayloadModel.cs
+src/Databox/Model/PushData.cs
+src/Databox/Model/PushDataAttribute.cs
+src/Databox/Model/State.cs
diff --git a/src/Databox.sln b/src/Databox.sln
index 7cd9cc2..e117efe 100644
--- a/src/Databox.sln
+++ b/src/Databox.sln
@@ -2,7 +2,7 @@ Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 2012
VisualStudioVersion = 12.0.0.0
MinimumVisualStudioVersion = 10.0.0.1
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Databox", "src\Databox\Databox.csproj", "{0DEDE14F-8852-43F9-AC99-C5304C96F2C5}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Databox", "src\Databox\Databox.csproj", "{3369FC28-30F0-48CC-BE06-FB64C77CEDE7}"
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Databox.Test", "src\Databox.Test\Databox.Test.csproj", "{19F1DEBC-DE5E-4517-8062-F000CD499087}"
EndProject
@@ -12,10 +12,10 @@ Global
Release|Any CPU = Release|Any CPU
EndGlobalSection
GlobalSection(ProjectConfigurationPlatforms) = postSolution
- {0DEDE14F-8852-43F9-AC99-C5304C96F2C5}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
- {0DEDE14F-8852-43F9-AC99-C5304C96F2C5}.Debug|Any CPU.Build.0 = Debug|Any CPU
- {0DEDE14F-8852-43F9-AC99-C5304C96F2C5}.Release|Any CPU.ActiveCfg = Release|Any CPU
- {0DEDE14F-8852-43F9-AC99-C5304C96F2C5}.Release|Any CPU.Build.0 = Release|Any CPU
+ {3369FC28-30F0-48CC-BE06-FB64C77CEDE7}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {3369FC28-30F0-48CC-BE06-FB64C77CEDE7}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {3369FC28-30F0-48CC-BE06-FB64C77CEDE7}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {3369FC28-30F0-48CC-BE06-FB64C77CEDE7}.Release|Any CPU.Build.0 = Release|Any CPU
{19F1DEBC-DE5E-4517-8062-F000CD499087}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
{19F1DEBC-DE5E-4517-8062-F000CD499087}.Debug|Any CPU.Build.0 = Debug|Any CPU
{19F1DEBC-DE5E-4517-8062-F000CD499087}.Release|Any CPU.ActiveCfg = Release|Any CPU
diff --git a/src/README.md b/src/README.md
index 1259055..530d4e1 100644
--- a/src/README.md
+++ b/src/README.md
@@ -4,8 +4,8 @@ Push API resources Open API documentation
This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:
-- API version: 1.0
-- SDK version: 0.0.2
+- API version: 0.4.4-alpha.4
+- SDK version: 0.0.3
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen
@@ -107,20 +107,23 @@ namespace Example
{
Configuration config = new Configuration();
- config.BasePath = "http://localhost:8080/q/openapi";
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
// create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
HttpClient httpClient = new HttpClient();
HttpClientHandler httpClientHandler = new HttpClientHandler();
var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
- var payloadModel = new PayloadModel?(); // PayloadModel? | (optional)
try
{
- apiInstance.RootPost(payloadModel);
+ apiInstance.DataDelete();
}
catch (ApiException e)
{
- Debug.Print("Exception when calling DefaultApi.RootPost: " + e.Message );
+ Debug.Print("Exception when calling DefaultApi.DataDelete: " + e.Message );
Debug.Print("Status Code: "+ e.ErrorCode);
Debug.Print(e.StackTrace);
}
@@ -133,19 +136,25 @@ namespace Example
## Documentation for API Endpoints
-All URIs are relative to *http://localhost:8080/q/openapi*
+All URIs are relative to *https://push.databox.com*
Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
-*DefaultApi* | [**RootPost**](docs/DefaultApi.md#rootpost) | **POST** / |
+*DefaultApi* | [**DataDelete**](docs/DefaultApi.md#datadelete) | **DELETE** /data |
+*DefaultApi* | [**DataMetricKeyDelete**](docs/DefaultApi.md#datametrickeydelete) | **DELETE** /data/{metricKey} |
+*DefaultApi* | [**DataPost**](docs/DefaultApi.md#datapost) | **POST** /data |
+*DefaultApi* | [**MetrickeysGet**](docs/DefaultApi.md#metrickeysget) | **GET** /metrickeys |
+*DefaultApi* | [**MetrickeysPost**](docs/DefaultApi.md#metrickeyspost) | **POST** /metrickeys |
+*DefaultApi* | [**PingGet**](docs/DefaultApi.md#pingget) | **GET** /ping |
## Documentation for Models
- [Model.ApiResponse](docs/ApiResponse.md)
- - [Model.PayloadDataModel](docs/PayloadDataModel.md)
- - [Model.PayloadModel](docs/PayloadModel.md)
+ - [Model.PushData](docs/PushData.md)
+ - [Model.PushDataAttribute](docs/PushDataAttribute.md)
+ - [Model.State](docs/State.md)
diff --git a/src/api/openapi.yaml b/src/api/openapi.yaml
index a7b357d..438b1f6 100644
--- a/src/api/openapi.yaml
+++ b/src/api/openapi.yaml
@@ -2,97 +2,125 @@ openapi: 3.0.3
info:
description: Push API resources Open API documentation
title: Static OpenAPI document of Push API resource
- version: "1.0"
+ version: 0.4.4-alpha.4
servers:
- description: Dev mode server description
- url: http://localhost:8080/q/openapi
+ url: https://push.databox.com
+security:
+- basicAuth: []
paths:
- /:
+ /metrickeys:
+ get:
+ responses:
+ "200":
+ description: OK
post:
requestBody:
content:
application/json:
schema:
- $ref: '#/components/schemas/PayloadModel'
+ type: object
+ application/vnd.databox.v2+json:
+ schema:
+ type: object
+ responses:
+ "200":
+ description: OK
+ /ping:
+ get:
+ responses:
+ "200":
+ description: OK
+ /data:
+ delete:
+ responses:
+ "200":
+ description: OK
+ post:
+ requestBody:
+ content:
+ application/json:
+ schema:
+ items:
+ $ref: '#/components/schemas/PushData'
+ type: array
+ application/vnd.databox.v2+json:
+ schema:
+ items:
+ $ref: '#/components/schemas/PushData'
+ type: array
+ responses:
+ "200":
+ description: OK
+ /data/{metricKey}:
+ delete:
+ parameters:
+ - explode: false
+ in: path
+ name: metricKey
+ required: true
+ schema:
+ type: string
+ style: simple
responses:
"200":
- content:
- application/json:
- example:
- status: OK
- message: ""
description: OK
- "400":
- content:
- application/json:
- example:
- status: Bad Request
- message: Bad request - Exceeded request count limit!
- description: Bad Request
- "401":
- content:
- application/json:
- example:
- status: Unauthorized
- message: Unauthorized - Invalid token!
- description: Unauthorized
- "500":
- content:
- application/json:
- example:
- status: Internal Server Error
- message: An unhandled exception occurred while processing your request!
- description: Internal Server Error
components:
schemas:
- PayloadModel:
+ ApiResponse:
+ properties:
+ status:
+ type: string
+ message:
+ type: string
+ type: object
+ PushData:
example:
- data:
- - $: 123.4
- date: 2021-03-01 00:00:00
- : Organic
- unit: USD
- - $: 123.4
- periodFrom: 2021-03-01 00:00:00
- periodTo: 2021-03-16 00:00:00
- : Organic
- unit: USD
+ date: date
+ periodTo: periodTo
+ unit: unit
+ periodFrom: periodFrom
+ attributes:
+ - value: value
+ key: key
+ - value: value
+ key: key
+ value: 0.8008282
+ key: key
properties:
- data:
+ attributes:
items:
- $ref: '#/components/schemas/PayloadDataModel'
+ $ref: '#/components/schemas/PushDataAttribute'
type: array
- type: object
- PayloadDataModel:
- properties:
- $:
- description: example metric name would be '$sales'
- type: number
- :
- description: example dimension would be 'channel'
+ date:
type: string
- unit:
+ key:
type: string
periodFrom:
- description: required if date not provided
type: string
periodTo:
- description: required if date not provided
type: string
- date:
- description: required periods not provided
+ unit:
type: string
- required:
- - "$,"
- - date
+ value:
+ format: float
+ type: number
type: object
- ApiResponse:
+ PushDataAttribute:
+ example:
+ value: value
+ key: key
properties:
- status:
+ key:
type: string
- message:
+ value:
type: string
type: object
+ State:
+ enum:
+ - DOWN
+ - UP
+ type: string
securitySchemes:
basicAuth:
scheme: basic
diff --git a/src/docs/DefaultApi.md b/src/docs/DefaultApi.md
index 6d306c4..eee4b89 100644
--- a/src/docs/DefaultApi.md
+++ b/src/docs/DefaultApi.md
@@ -1,14 +1,19 @@
# Databox.Api.DefaultApi
-All URIs are relative to *http://localhost:8080/q/openapi*
+All URIs are relative to *https://push.databox.com*
| Method | HTTP request | Description |
|--------|--------------|-------------|
-| [**RootPost**](DefaultApi.md#rootpost) | **POST** / | |
+| [**DataDelete**](DefaultApi.md#datadelete) | **DELETE** /data | |
+| [**DataMetricKeyDelete**](DefaultApi.md#datametrickeydelete) | **DELETE** /data/{metricKey} | |
+| [**DataPost**](DefaultApi.md#datapost) | **POST** /data | |
+| [**MetrickeysGet**](DefaultApi.md#metrickeysget) | **GET** /metrickeys | |
+| [**MetrickeysPost**](DefaultApi.md#metrickeyspost) | **POST** /metrickeys | |
+| [**PingGet**](DefaultApi.md#pingget) | **GET** /ping | |
-
-# **RootPost**
-> void RootPost (PayloadModel? payloadModel = null)
+
+# **DataDelete**
+> void DataDelete ()
@@ -23,25 +28,296 @@ using Databox.Model;
namespace Example
{
- public class RootPostExample
+ public class DataDeleteExample
{
public static void Main()
{
Configuration config = new Configuration();
- config.BasePath = "http://localhost:8080/q/openapi";
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+
+ try
+ {
+ apiInstance.DataDelete();
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataDelete: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataDeleteWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataDeleteWithHttpInfo();
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataDeleteWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+This endpoint does not need any parameter.
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **DataMetricKeyDelete**
+> void DataMetricKeyDelete (string metricKey)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class DataMetricKeyDeleteExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var metricKey = "metricKey_example"; // string |
+
+ try
+ {
+ apiInstance.DataMetricKeyDelete(metricKey);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataMetricKeyDelete: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataMetricKeyDeleteWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataMetricKeyDeleteWithHttpInfo(metricKey);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataMetricKeyDeleteWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+
+| Name | Type | Description | Notes |
+|------|------|-------------|-------|
+| **metricKey** | **string** | | |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **DataPost**
+> void DataPost (List? pushData = null)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class DataPostExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var pushData = new List?(); // List? | (optional)
+
+ try
+ {
+ apiInstance.DataPost(pushData);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.DataPost: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the DataPostWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.DataPostWithHttpInfo(pushData);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.DataPostWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+
+| Name | Type | Description | Notes |
+|------|------|-------------|-------|
+| **pushData** | [**List<PushData>?**](PushData.md) | | [optional] |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: application/json, application/vnd.databox.v2+json
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **MetrickeysGet**
+> void MetrickeysGet ()
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class MetrickeysGetExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
// create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
HttpClient httpClient = new HttpClient();
HttpClientHandler httpClientHandler = new HttpClientHandler();
var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
- var payloadModel = new PayloadModel?(); // PayloadModel? | (optional)
try
{
- apiInstance.RootPost(payloadModel);
+ apiInstance.MetrickeysGet();
}
catch (ApiException e)
{
- Debug.Print("Exception when calling DefaultApi.RootPost: " + e.Message);
+ Debug.Print("Exception when calling DefaultApi.MetrickeysGet: " + e.Message);
Debug.Print("Status Code: " + e.ErrorCode);
Debug.Print(e.StackTrace);
}
@@ -50,17 +326,104 @@ namespace Example
}
```
-#### Using the RootPostWithHttpInfo variant
+#### Using the MetrickeysGetWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.
```csharp
try
{
- apiInstance.RootPostWithHttpInfo(payloadModel);
+ apiInstance.MetrickeysGetWithHttpInfo();
}
catch (ApiException e)
{
- Debug.Print("Exception when calling DefaultApi.RootPostWithHttpInfo: " + e.Message);
+ Debug.Print("Exception when calling DefaultApi.MetrickeysGetWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+
+### Parameters
+This endpoint does not need any parameter.
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **MetrickeysPost**
+> void MetrickeysPost (Object? body = null)
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class MetrickeysPostExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+ var body = null; // Object? | (optional)
+
+ try
+ {
+ apiInstance.MetrickeysPost(body);
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.MetrickeysPost: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the MetrickeysPostWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.MetrickeysPostWithHttpInfo(body);
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.MetrickeysPostWithHttpInfo: " + e.Message);
Debug.Print("Status Code: " + e.ErrorCode);
Debug.Print(e.StackTrace);
}
@@ -70,29 +433,112 @@ catch (ApiException e)
| Name | Type | Description | Notes |
|------|------|-------------|-------|
-| **payloadModel** | [**PayloadModel?**](PayloadModel?.md) | | [optional] |
+| **body** | **Object?** | | [optional] |
+
+### Return type
+
+void (empty response body)
+
+### Authorization
+
+[basicAuth](../README.md#basicAuth)
+
+### HTTP request headers
+
+ - **Content-Type**: application/json, application/vnd.databox.v2+json
+ - **Accept**: Not defined
+
+
+### HTTP response details
+| Status code | Description | Response headers |
+|-------------|-------------|------------------|
+| **200** | OK | - |
+
+[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
+
+
+# **PingGet**
+> void PingGet ()
+
+
+
+### Example
+```csharp
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Net.Http;
+using Databox.Api;
+using Databox.Client;
+using Databox.Model;
+
+namespace Example
+{
+ public class PingGetExample
+ {
+ public static void Main()
+ {
+ Configuration config = new Configuration();
+ config.BasePath = "https://push.databox.com";
+ // Configure HTTP basic authorization: basicAuth
+ config.Username = "YOUR_USERNAME";
+ config.Password = "YOUR_PASSWORD";
+
+ // create instances of HttpClient, HttpClientHandler to be reused later with different Api classes
+ HttpClient httpClient = new HttpClient();
+ HttpClientHandler httpClientHandler = new HttpClientHandler();
+ var apiInstance = new DefaultApi(httpClient, config, httpClientHandler);
+
+ try
+ {
+ apiInstance.PingGet();
+ }
+ catch (ApiException e)
+ {
+ Debug.Print("Exception when calling DefaultApi.PingGet: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+ }
+ }
+ }
+}
+```
+
+#### Using the PingGetWithHttpInfo variant
+This returns an ApiResponse object which contains the response data, status code and headers.
+
+```csharp
+try
+{
+ apiInstance.PingGetWithHttpInfo();
+}
+catch (ApiException e)
+{
+ Debug.Print("Exception when calling DefaultApi.PingGetWithHttpInfo: " + e.Message);
+ Debug.Print("Status Code: " + e.ErrorCode);
+ Debug.Print(e.StackTrace);
+}
+```
+### Parameters
+This endpoint does not need any parameter.
### Return type
void (empty response body)
### Authorization
-No authorization required
+[basicAuth](../README.md#basicAuth)
### HTTP request headers
- - **Content-Type**: application/json
- - **Accept**: application/json
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK | - |
-| **400** | Bad Request | - |
-| **401** | Unauthorized | - |
-| **500** | Internal Server Error | - |
[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
diff --git a/src/docs/PayloadDataModel.md b/src/docs/PayloadDataModel.md
deleted file mode 100644
index 7f876df..0000000
--- a/src/docs/PayloadDataModel.md
+++ /dev/null
@@ -1,15 +0,0 @@
-# Databox.Model.PayloadDataModel
-
-## Properties
-
-Name | Type | Description | Notes
------------- | ------------- | ------------- | -------------
-**MetricName** | **decimal** | example metric name would be '$sales' | [optional]
-**DimensionName** | **string** | example dimension would be 'channel' | [optional]
-**Unit** | **string** | | [optional]
-**PeriodFrom** | **string** | required if date not provided | [optional]
-**PeriodTo** | **string** | required if date not provided | [optional]
-**Date** | **string** | required periods not provided |
-
-[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
-
diff --git a/src/docs/PushData.md b/src/docs/PushData.md
new file mode 100644
index 0000000..82b456d
--- /dev/null
+++ b/src/docs/PushData.md
@@ -0,0 +1,16 @@
+# Databox.Model.PushData
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+**Attributes** | [**List<PushDataAttribute>**](PushDataAttribute.md) | | [optional]
+**Date** | **string** | | [optional]
+**Key** | **string** | | [optional]
+**PeriodFrom** | **string** | | [optional]
+**PeriodTo** | **string** | | [optional]
+**Unit** | **string** | | [optional]
+**Value** | **float** | | [optional]
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/src/docs/PushDataAttribute.md b/src/docs/PushDataAttribute.md
new file mode 100644
index 0000000..2f164c8
--- /dev/null
+++ b/src/docs/PushDataAttribute.md
@@ -0,0 +1,11 @@
+# Databox.Model.PushDataAttribute
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+**Key** | **string** | | [optional]
+**Value** | **string** | | [optional]
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/src/docs/State.md b/src/docs/State.md
new file mode 100644
index 0000000..f6636e1
--- /dev/null
+++ b/src/docs/State.md
@@ -0,0 +1,9 @@
+# Databox.Model.State
+
+## Properties
+
+Name | Type | Description | Notes
+------------ | ------------- | ------------- | -------------
+
+[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
+
diff --git a/src/src/Databox.Test/Api/DefaultApiTests.cs b/src/src/Databox.Test/Api/DefaultApiTests.cs
index c7ca94d..955faac 100644
--- a/src/src/Databox.Test/Api/DefaultApiTests.cs
+++ b/src/src/Databox.Test/Api/DefaultApiTests.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -54,14 +54,66 @@ public void InstanceTest()
}
///
- /// Test RootPost
+ /// Test DataDelete
///
[Fact]
- public void RootPostTest()
+ public void DataDeleteTest()
{
// TODO uncomment below to test the method and replace null with proper value
- //PayloadModel? payloadModel = null;
- //instance.RootPost(payloadModel);
+ //instance.DataDelete();
+ }
+
+ ///
+ /// Test DataMetricKeyDelete
+ ///
+ [Fact]
+ public void DataMetricKeyDeleteTest()
+ {
+ // TODO uncomment below to test the method and replace null with proper value
+ //string metricKey = null;
+ //instance.DataMetricKeyDelete(metricKey);
+ }
+
+ ///
+ /// Test DataPost
+ ///
+ [Fact]
+ public void DataPostTest()
+ {
+ // TODO uncomment below to test the method and replace null with proper value
+ //List? pushData = null;
+ //instance.DataPost(pushData);
+ }
+
+ ///
+ /// Test MetrickeysGet
+ ///
+ [Fact]
+ public void MetrickeysGetTest()
+ {
+ // TODO uncomment below to test the method and replace null with proper value
+ //instance.MetrickeysGet();
+ }
+
+ ///
+ /// Test MetrickeysPost
+ ///
+ [Fact]
+ public void MetrickeysPostTest()
+ {
+ // TODO uncomment below to test the method and replace null with proper value
+ //Object? body = null;
+ //instance.MetrickeysPost(body);
+ }
+
+ ///
+ /// Test PingGet
+ ///
+ [Fact]
+ public void PingGetTest()
+ {
+ // TODO uncomment below to test the method and replace null with proper value
+ //instance.PingGet();
}
}
}
diff --git a/src/src/Databox.Test/Model/ApiResponseTests.cs b/src/src/Databox.Test/Model/ApiResponseTests.cs
index 0693ed8..c924efe 100644
--- a/src/src/Databox.Test/Model/ApiResponseTests.cs
+++ b/src/src/Databox.Test/Model/ApiResponseTests.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox.Test/Model/PushDataAttributeTests.cs b/src/src/Databox.Test/Model/PushDataAttributeTests.cs
new file mode 100644
index 0000000..60abfa3
--- /dev/null
+++ b/src/src/Databox.Test/Model/PushDataAttributeTests.cs
@@ -0,0 +1,75 @@
+/*
+ * Static OpenAPI document of Push API resource
+ *
+ * Push API resources Open API documentation
+ *
+ * The version of the OpenAPI document: 0.4.4-alpha.4
+ * Generated by: https://github.com/openapitools/openapi-generator.git
+ */
+
+
+using Xunit;
+
+using System;
+using System.Linq;
+using System.IO;
+using System.Collections.Generic;
+using Databox.Model;
+using Databox.Client;
+using System.Reflection;
+using Newtonsoft.Json;
+
+namespace Databox.Test.Model
+{
+ ///
+ /// Class for testing PushDataAttribute
+ ///
+ ///
+ /// This file is automatically generated by OpenAPI Generator (https://openapi-generator.tech).
+ /// Please update the test case below to test the model.
+ ///
+ public class PushDataAttributeTests : IDisposable
+ {
+ // TODO uncomment below to declare an instance variable for PushDataAttribute
+ //private PushDataAttribute instance;
+
+ public PushDataAttributeTests()
+ {
+ // TODO uncomment below to create an instance of PushDataAttribute
+ //instance = new PushDataAttribute();
+ }
+
+ public void Dispose()
+ {
+ // Cleanup when everything is done.
+ }
+
+ ///
+ /// Test an instance of PushDataAttribute
+ ///
+ [Fact]
+ public void PushDataAttributeInstanceTest()
+ {
+ // TODO uncomment below to test "IsType" PushDataAttribute
+ //Assert.IsType(instance);
+ }
+
+ ///
+ /// Test the property 'Key'
+ ///
+ [Fact]
+ public void KeyTest()
+ {
+ // TODO unit test for the property 'Key'
+ }
+
+ ///
+ /// Test the property 'Value'
+ ///
+ [Fact]
+ public void ValueTest()
+ {
+ // TODO unit test for the property 'Value'
+ }
+ }
+}
diff --git a/src/src/Databox/Api/DefaultApi.cs b/src/src/Databox/Api/DefaultApi.cs
index 7e609cb..aec054a 100644
--- a/src/src/Databox/Api/DefaultApi.cs
+++ b/src/src/Databox/Api/DefaultApi.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -31,9 +31,8 @@ public interface IDefaultApiSync : IApiAccessor
///
///
/// Thrown when fails to make API call
- /// (optional)
///
- void RootPost(PayloadModel? payloadModel = default(PayloadModel?));
+ void DataDelete();
///
///
@@ -42,9 +41,94 @@ public interface IDefaultApiSync : IApiAccessor
///
///
/// Thrown when fails to make API call
- /// (optional)
/// ApiResponse of Object(void)
- ApiResponse
/// Thrown when fails to make API call
- /// (optional)
/// Cancellation Token to cancel the request.
/// Task of void
- public async System.Threading.Tasks.Task RootPostAsync(PayloadModel? payloadModel = default(PayloadModel?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ public async System.Threading.Tasks.Task DataDeleteAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
{
- await RootPostWithHttpInfoAsync(payloadModel, cancellationToken).ConfigureAwait(false);
+ await DataDeleteWithHttpInfoAsync(cancellationToken).ConfigureAwait(false);
}
///
///
///
/// Thrown when fails to make API call
- /// (optional)
/// Cancellation Token to cancel the request.
/// Task of ApiResponse
- public async System.Threading.Tasks.Task> RootPostWithHttpInfoAsync(PayloadModel? payloadModel = default(PayloadModel?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ public async System.Threading.Tasks.Task> DataDeleteWithHttpInfoAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
{
Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
string[] _contentTypes = new string[] {
- "application/json"
};
// to determine the Accept header
string[] _accepts = new string[] {
- "application/json"
};
@@ -381,16 +571,600 @@ public Databox.Client.ExceptionFactory ExceptionFactory
var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
- localVarRequestOptions.Data = payloadModel;
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+
+ var localVarResponse = await this.AsynchronousClient.DeleteAsync("/data", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("DataDelete", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ ///
+ public void DataMetricKeyDelete(string metricKey)
+ {
+ DataMetricKeyDeleteWithHttpInfo(metricKey);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ /// ApiResponse of Object(void)
+ public Databox.Client.ApiResponse DataMetricKeyDeleteWithHttpInfo(string metricKey)
+ {
+ // verify the required parameter 'metricKey' is set
+ if (metricKey == null)
+ throw new Databox.Client.ApiException(400, "Missing required parameter 'metricKey' when calling DefaultApi->DataMetricKeyDelete");
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.PathParameters.Add("metricKey", Databox.Client.ClientUtils.ParameterToString(metricKey)); // path parameter
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+ var localVarResponse = this.Client.Delete("/data/{metricKey}", localVarRequestOptions, this.Configuration);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("DataMetricKeyDelete", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ /// Cancellation Token to cancel the request.
+ /// Task of void
+ public async System.Threading.Tasks.Task DataMetricKeyDeleteAsync(string metricKey, System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ await DataMetricKeyDeleteWithHttpInfoAsync(metricKey, cancellationToken).ConfigureAwait(false);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ /// Cancellation Token to cancel the request.
+ /// Task of ApiResponse
+ public async System.Threading.Tasks.Task> DataMetricKeyDeleteWithHttpInfoAsync(string metricKey, System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ // verify the required parameter 'metricKey' is set
+ if (metricKey == null)
+ throw new Databox.Client.ApiException(400, "Missing required parameter 'metricKey' when calling DefaultApi->DataMetricKeyDelete");
+
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.PathParameters.Add("metricKey", Databox.Client.ClientUtils.ParameterToString(metricKey)); // path parameter
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+
+ var localVarResponse = await this.AsynchronousClient.DeleteAsync("/data/{metricKey}", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("DataMetricKeyDelete", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ ///
+ public void DataPost(List? pushData = default(List?))
+ {
+ DataPostWithHttpInfo(pushData);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// ApiResponse of Object(void)
+ public Databox.Client.ApiResponse DataPostWithHttpInfo(List? pushData = default(List?))
+ {
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ "application/json",
+ "application/vnd.databox.v2+json"
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.Data = pushData;
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+ var localVarResponse = this.Client.Post("/data", localVarRequestOptions, this.Configuration);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("DataPost", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// Cancellation Token to cancel the request.
+ /// Task of void
+ public async System.Threading.Tasks.Task DataPostAsync(List? pushData = default(List?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ await DataPostWithHttpInfoAsync(pushData, cancellationToken).ConfigureAwait(false);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// Cancellation Token to cancel the request.
+ /// Task of ApiResponse
+ public async System.Threading.Tasks.Task> DataPostWithHttpInfoAsync(List? pushData = default(List?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ "application/json",
+ "application/vnd.databox.v2+json"
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.Data = pushData;
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+
+ var localVarResponse = await this.AsynchronousClient.PostAsync("/data", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("DataPost", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ public void MetrickeysGet()
+ {
+ MetrickeysGetWithHttpInfo();
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// ApiResponse of Object(void)
+ public Databox.Client.ApiResponse MetrickeysGetWithHttpInfo()
+ {
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+ var localVarResponse = this.Client.Get("/metrickeys", localVarRequestOptions, this.Configuration);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("MetrickeysGet", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// Cancellation Token to cancel the request.
+ /// Task of void
+ public async System.Threading.Tasks.Task MetrickeysGetAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ await MetrickeysGetWithHttpInfoAsync(cancellationToken).ConfigureAwait(false);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// Cancellation Token to cancel the request.
+ /// Task of ApiResponse
+ public async System.Threading.Tasks.Task> MetrickeysGetWithHttpInfoAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+
+ var localVarResponse = await this.AsynchronousClient.GetAsync("/metrickeys", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("MetrickeysGet", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ ///
+ public void MetrickeysPost(Object? body = default(Object?))
+ {
+ MetrickeysPostWithHttpInfo(body);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// ApiResponse of Object(void)
+ public Databox.Client.ApiResponse MetrickeysPostWithHttpInfo(Object? body = default(Object?))
+ {
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ "application/json",
+ "application/vnd.databox.v2+json"
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.Data = body;
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+ var localVarResponse = this.Client.Post("/metrickeys", localVarRequestOptions, this.Configuration);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("MetrickeysPost", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// Cancellation Token to cancel the request.
+ /// Task of void
+ public async System.Threading.Tasks.Task MetrickeysPostAsync(Object? body = default(Object?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ await MetrickeysPostWithHttpInfoAsync(body, cancellationToken).ConfigureAwait(false);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// (optional)
+ /// Cancellation Token to cancel the request.
+ /// Task of ApiResponse
+ public async System.Threading.Tasks.Task> MetrickeysPostWithHttpInfoAsync(Object? body = default(Object?), System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ "application/json",
+ "application/vnd.databox.v2+json"
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+ localVarRequestOptions.Data = body;
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+
+ var localVarResponse = await this.AsynchronousClient.PostAsync("/metrickeys", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("MetrickeysPost", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ ///
+ public void PingGet()
+ {
+ PingGetWithHttpInfo();
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// ApiResponse of Object(void)
+ public Databox.Client.ApiResponse PingGetWithHttpInfo()
+ {
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
+
+ // make the HTTP request
+ var localVarResponse = this.Client.Get("/ping", localVarRequestOptions, this.Configuration);
+
+ if (this.ExceptionFactory != null)
+ {
+ Exception _exception = this.ExceptionFactory("PingGet", localVarResponse);
+ if (_exception != null) throw _exception;
+ }
+
+ return localVarResponse;
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// Cancellation Token to cancel the request.
+ /// Task of void
+ public async System.Threading.Tasks.Task PingGetAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+ await PingGetWithHttpInfoAsync(cancellationToken).ConfigureAwait(false);
+ }
+
+ ///
+ ///
+ ///
+ /// Thrown when fails to make API call
+ /// Cancellation Token to cancel the request.
+ /// Task of ApiResponse
+ public async System.Threading.Tasks.Task> PingGetWithHttpInfoAsync(System.Threading.CancellationToken cancellationToken = default(System.Threading.CancellationToken))
+ {
+
+ Databox.Client.RequestOptions localVarRequestOptions = new Databox.Client.RequestOptions();
+
+ string[] _contentTypes = new string[] {
+ };
+
+ // to determine the Accept header
+ string[] _accepts = new string[] {
+ };
+
+
+ var localVarContentType = Databox.Client.ClientUtils.SelectHeaderContentType(_contentTypes);
+ if (localVarContentType != null) localVarRequestOptions.HeaderParameters.Add("Content-Type", localVarContentType);
+
+ var localVarAccept = Databox.Client.ClientUtils.SelectHeaderAccept(_accepts);
+ if (localVarAccept != null) localVarRequestOptions.HeaderParameters.Add("Accept", localVarAccept);
+
+
+ // authentication (basicAuth) required
+ // http basic authentication required
+ if (!string.IsNullOrEmpty(this.Configuration.Username) || !string.IsNullOrEmpty(this.Configuration.Password) && !localVarRequestOptions.HeaderParameters.ContainsKey("Authorization"))
+ {
+ localVarRequestOptions.HeaderParameters.Add("Authorization", "Basic " + Databox.Client.ClientUtils.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password));
+ }
// make the HTTP request
- var localVarResponse = await this.AsynchronousClient.PostAsync("/", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
+ var localVarResponse = await this.AsynchronousClient.GetAsync("/ping", localVarRequestOptions, this.Configuration, cancellationToken).ConfigureAwait(false);
if (this.ExceptionFactory != null)
{
- Exception _exception = this.ExceptionFactory("RootPost", localVarResponse);
+ Exception _exception = this.ExceptionFactory("PingGet", localVarResponse);
if (_exception != null) throw _exception;
}
diff --git a/src/src/Databox/Client/ApiClient.cs b/src/src/Databox/Client/ApiClient.cs
index 1c00801..1e59f59 100644
--- a/src/src/Databox/Client/ApiClient.cs
+++ b/src/src/Databox/Client/ApiClient.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/ApiException.cs b/src/src/Databox/Client/ApiException.cs
index 5e5c5c0..b49a213 100644
--- a/src/src/Databox/Client/ApiException.cs
+++ b/src/src/Databox/Client/ApiException.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/ApiResponse.cs b/src/src/Databox/Client/ApiResponse.cs
index 07a07ea..5a47fc1 100644
--- a/src/src/Databox/Client/ApiResponse.cs
+++ b/src/src/Databox/Client/ApiResponse.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/ClientUtils.cs b/src/src/Databox/Client/ClientUtils.cs
index 999ca05..bc66365 100644
--- a/src/src/Databox/Client/ClientUtils.cs
+++ b/src/src/Databox/Client/ClientUtils.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/ExceptionFactory.cs b/src/src/Databox/Client/ExceptionFactory.cs
index 51d8f21..5b7376e 100644
--- a/src/src/Databox/Client/ExceptionFactory.cs
+++ b/src/src/Databox/Client/ExceptionFactory.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/FileParameter.cs b/src/src/Databox/Client/FileParameter.cs
index a2b6b62..dfb6cb6 100644
--- a/src/src/Databox/Client/FileParameter.cs
+++ b/src/src/Databox/Client/FileParameter.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/GlobalConfiguration.cs b/src/src/Databox/Client/GlobalConfiguration.cs
index 04464d2..bb7861d 100644
--- a/src/src/Databox/Client/GlobalConfiguration.cs
+++ b/src/src/Databox/Client/GlobalConfiguration.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/IApiAccessor.cs b/src/src/Databox/Client/IApiAccessor.cs
index 74ab2af..662e142 100644
--- a/src/src/Databox/Client/IApiAccessor.cs
+++ b/src/src/Databox/Client/IApiAccessor.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/IAsynchronousClient.cs b/src/src/Databox/Client/IAsynchronousClient.cs
index bc69fd9..ec6eb58 100644
--- a/src/src/Databox/Client/IAsynchronousClient.cs
+++ b/src/src/Databox/Client/IAsynchronousClient.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/IReadableConfiguration.cs b/src/src/Databox/Client/IReadableConfiguration.cs
index e1d3190..adbbe10 100644
--- a/src/src/Databox/Client/IReadableConfiguration.cs
+++ b/src/src/Databox/Client/IReadableConfiguration.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/ISynchronousClient.cs b/src/src/Databox/Client/ISynchronousClient.cs
index d647d91..7adedad 100644
--- a/src/src/Databox/Client/ISynchronousClient.cs
+++ b/src/src/Databox/Client/ISynchronousClient.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/Multimap.cs b/src/src/Databox/Client/Multimap.cs
index 81aeded..df89a51 100644
--- a/src/src/Databox/Client/Multimap.cs
+++ b/src/src/Databox/Client/Multimap.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/OpenAPIDateConverter.cs b/src/src/Databox/Client/OpenAPIDateConverter.cs
index 7a30336..f5eb19d 100644
--- a/src/src/Databox/Client/OpenAPIDateConverter.cs
+++ b/src/src/Databox/Client/OpenAPIDateConverter.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/RequestOptions.cs b/src/src/Databox/Client/RequestOptions.cs
index 2c6202d..8b2c3a3 100644
--- a/src/src/Databox/Client/RequestOptions.cs
+++ b/src/src/Databox/Client/RequestOptions.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/RetryConfiguration.cs b/src/src/Databox/Client/RetryConfiguration.cs
index 998d91c..f30b2a2 100644
--- a/src/src/Databox/Client/RetryConfiguration.cs
+++ b/src/src/Databox/Client/RetryConfiguration.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Client/WebRequestPathBuilder.cs b/src/src/Databox/Client/WebRequestPathBuilder.cs
index 51e4d35..2181481 100644
--- a/src/src/Databox/Client/WebRequestPathBuilder.cs
+++ b/src/src/Databox/Client/WebRequestPathBuilder.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Databox.csproj b/src/src/Databox/Databox.csproj
index 7b0d637..7703afa 100644
--- a/src/src/Databox/Databox.csproj
+++ b/src/src/Databox/Databox.csproj
@@ -12,7 +12,7 @@
A library generated from a OpenAPI doc
No Copyright
Databox
- 0.0.2
+ 0.0.3
bin\$(Configuration)\$(TargetFramework)\Databox.xml
https://github.com/GIT_USER_ID/GIT_REPO_ID.git
git
diff --git a/src/src/Databox/Model/AbstractOpenAPISchema.cs b/src/src/Databox/Model/AbstractOpenAPISchema.cs
index b9e1edf..014e8aa 100644
--- a/src/src/Databox/Model/AbstractOpenAPISchema.cs
+++ b/src/src/Databox/Model/AbstractOpenAPISchema.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Model/ApiResponse.cs b/src/src/Databox/Model/ApiResponse.cs
index 1850509..360c042 100644
--- a/src/src/Databox/Model/ApiResponse.cs
+++ b/src/src/Databox/Model/ApiResponse.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Model/State.cs b/src/src/Databox/Model/State.cs
new file mode 100644
index 0000000..6a15633
--- /dev/null
+++ b/src/src/Databox/Model/State.cs
@@ -0,0 +1,48 @@
+/*
+ * Static OpenAPI document of Push API resource
+ *
+ * Push API resources Open API documentation
+ *
+ * The version of the OpenAPI document: 0.4.4-alpha.4
+ * Generated by: https://github.com/openapitools/openapi-generator.git
+ */
+
+
+using System;
+using System.Collections;
+using System.Collections.Generic;
+using System.Collections.ObjectModel;
+using System.Linq;
+using System.IO;
+using System.Runtime.Serialization;
+using System.Text;
+using System.Text.RegularExpressions;
+using Newtonsoft.Json;
+using Newtonsoft.Json.Converters;
+using Newtonsoft.Json.Linq;
+using System.ComponentModel.DataAnnotations;
+using FileParameter = Databox.Client.FileParameter;
+using OpenAPIDateConverter = Databox.Client.OpenAPIDateConverter;
+
+namespace Databox.Model
+{
+ ///
+ /// Defines State
+ ///
+ [JsonConverter(typeof(StringEnumConverter))]
+ public enum State
+ {
+ ///
+ /// Enum DOWN for value: DOWN
+ ///
+ [EnumMember(Value = "DOWN")]
+ DOWN = 1,
+
+ ///
+ /// Enum UP for value: UP
+ ///
+ [EnumMember(Value = "UP")]
+ UP = 2
+ }
+
+}
diff --git a/src/src/Databox.Test/Model/PayloadDataModelTests.cs b/src/src/Databox.Test/Model/PushDataTests.cs
similarity index 66%
rename from src/src/Databox.Test/Model/PayloadDataModelTests.cs
rename to src/src/Databox.Test/Model/PushDataTests.cs
index ac3bdaf..670feff 100644
--- a/src/src/Databox.Test/Model/PayloadDataModelTests.cs
+++ b/src/src/Databox.Test/Model/PushDataTests.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -22,21 +22,21 @@
namespace Databox.Test.Model
{
///
- /// Class for testing PayloadDataModel
+ /// Class for testing PushData
///
///
/// This file is automatically generated by OpenAPI Generator (https://openapi-generator.tech).
/// Please update the test case below to test the model.
///
- public class PayloadDataModelTests : IDisposable
+ public class PushDataTests : IDisposable
{
- // TODO uncomment below to declare an instance variable for PayloadDataModel
- //private PayloadDataModel instance;
+ // TODO uncomment below to declare an instance variable for PushData
+ //private PushData instance;
- public PayloadDataModelTests()
+ public PushDataTests()
{
// TODO uncomment below to create an instance of PayloadDataModel
//instance = new PayloadDataModel();
}
public void Dispose()
@@ -45,40 +45,40 @@ public void Dispose()
}
///
/// Test an instance of PayloadDataModel
///
[Fact]
- public void PayloadDataModelInstanceTest()
+ public void PushDataInstanceTest()
{
// TODO uncomment below to test "IsType" PayloadDataModel
//Assert.IsType(instance);
}
///
- /// Test the property 'MetricName'
+ /// Test the property 'Attributes'
///
[Fact]
- public void MetricNameTest()
+ public void AttributesTest()
{
// TODO unit test for the property 'MetricName'
}
///
- /// Test the property 'DimensionName'
+ /// Test the property 'Date'
///
[Fact]
- public void DimensionNameTest()
+ public void DateTest()
{
- // TODO unit test for the property 'DimensionName'
+ // TODO unit test for the property 'Date'
}
///
/// Test the property 'Unit'
///
[Fact]
- public void UnitTest()
+ public void KeyTest()
{
// TODO unit test for the property 'Unit'
}
///
@@ -100,12 +100,21 @@ public void PeriodToTest()
}
///
- /// Test the property 'Date'
+ /// Test the property 'Unit'
///
[Fact]
- public void DateTest()
+ public void UnitTest()
{
- // TODO unit test for the property 'Date'
+ // TODO unit test for the property 'Unit'
+ }
+
+ ///
+ /// Test the property 'Value'
+ ///
+ [Fact]
+ public void ValueTest()
+ {
+ // TODO unit test for the property 'Value'
}
}
}
@@ -22,21 +22,21 @@
{
- // TODO uncomment below to create an instance of PayloadDataModel
- //instance = new PayloadDataModel();
+ // TODO uncomment below to create an instance of PushData
+ //instance = new PushData();
}
public void Dispose()
@@ -45,40 +45,40 @@ public void Dispose()
}
///
- /// Test an instance of PayloadDataModel
+ /// Test an instance of PushData
///
[Fact]
@@ -45,40 +45,40 @@ public void Dispose()
{
- // TODO uncomment below to test "IsType" PayloadDataModel
- //Assert.IsType(instance);
+ // TODO uncomment below to test "IsType" PushData
+ //Assert.IsType(instance);
}
///
@@ -45,40 +45,40 @@ public void Dispose()
{
- // TODO unit test for the property 'MetricName'
+ // TODO unit test for the property 'Attributes'
}
///
@@ -45,40 +45,40 @@ public void Dispose()
}
///
- /// Test the property 'Unit'
+ /// Test the property 'Key'
///
[Fact]
@@ -45,40 +45,40 @@ public void Dispose()
{
- // TODO unit test for the property 'Unit'
+ // TODO unit test for the property 'Key'
}
///
diff --git a/src/src/Databox.Test/Model/PayloadModelTests.cs b/src/src/Databox.Test/Model/StateTests.cs
similarity index 54%
rename from src/src/Databox.Test/Model/PayloadModelTests.cs
rename to src/src/Databox.Test/Model/StateTests.cs
index b701de1..b9b33da 100644
--- a/src/src/Databox.Test/Model/PayloadModelTests.cs
+++ b/src/src/Databox.Test/Model/StateTests.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -22,21 +22,21 @@
namespace Databox.Test.Model
{
///
- /// Class for testing PayloadModel
+ /// Class for testing State
///
///
/// This file is automatically generated by OpenAPI Generator (https://openapi-generator.tech).
/// Please update the test case below to test the model.
///
- public class PayloadModelTests : IDisposable
+ public class StateTests : IDisposable
{
- // TODO uncomment below to declare an instance variable for PayloadModel
- //private PayloadModel instance;
+ // TODO uncomment below to declare an instance variable for State
+ //private State instance;
- public PayloadModelTests()
+ public StateTests()
{
// TODO uncomment below to create an instance of PayloadModel
//instance = new PayloadModel();
}
public void Dispose()
@@ -45,22 +45,13 @@ public void Dispose()
}
///
- /// Test an instance of PayloadModel
+ /// Test an instance of State
///
[Fact]
- public void PayloadModelInstanceTest()
+ public void StateInstanceTest()
{
- // TODO uncomment below to test "IsType" PayloadModel
- //Assert.IsType(instance);
- }
-
- ///
- /// Test the property 'Data'
- ///
- [Fact]
- public void DataTest()
- {
- // TODO unit test for the property 'Data'
+ // TODO uncomment below to test "IsType" State
+ //Assert.IsType(instance);
}
}
}
@@ -22,21 +22,21 @@
{
- // TODO uncomment below to create an instance of PayloadModel
- //instance = new PayloadModel();
+ // TODO uncomment below to create an instance of State
+ //instance = new State();
}
public void Dispose()
diff --git a/src/src/Databox/Client/Configuration.cs b/src/src/Databox/Client/Configuration.cs
index 9ebda38..324e2ba 100644
--- a/src/src/Databox/Client/Configuration.cs
+++ b/src/src/Databox/Client/Configuration.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
* The version of the OpenAPI document: 1.0
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -33,7 +33,7 @@ public class Configuration : IReadableConfiguration
/// Version of the package.
///
/// Version of the package.
- public const string Version = "0.0.2";
+ public const string Version = "0.0.3";
///
/// Identifier for ISO 8601 DateTime Format
@@ -117,8 +117,8 @@ public class Configuration : IReadableConfiguration
public Configuration()
{
Proxy = null;
- UserAgent = WebUtility.UrlEncode("OpenAPI-Generator/0.0.2/csharp");
- BasePath = "http://localhost:8080/q/openapi";
+ UserAgent = WebUtility.UrlEncode("OpenAPI-Generator/0.0.3/csharp");
+ BasePath = "https://push.databox.com";
DefaultHeaders = new ConcurrentDictionary();
ApiKey = new ConcurrentDictionary();
ApiKeyPrefix = new ConcurrentDictionary();
@@ -126,7 +126,7 @@ public Configuration()
{
{
new Dictionary {
- {"url", "http://localhost:8080/q/openapi"},
+ {"url", "https://push.databox.com"},
{"description", "Dev mode server description"},
}
}
@@ -147,7 +147,7 @@ public Configuration(
IDictionary defaultHeaders,
IDictionary apiKey,
IDictionary apiKeyPrefix,
- string basePath = "http://localhost:8080/q/openapi") : this()
+ string basePath = "https://push.databox.com") : this()
{
if (string.IsNullOrWhiteSpace(basePath))
throw new ArgumentException("The provided basePath is invalid.", "basePath");
@@ -539,8 +539,8 @@ public static string ToDebugReport()
string report = "C# SDK (Databox) Debug Report:\n";
report += " OS: " + System.Environment.OSVersion + "\n";
report += " .NET Framework Version: " + System.Environment.Version + "\n";
- report += " Version of the API: 1.0\n";
- report += " SDK Package Version: 0.0.2\n";
+ report += " Version of the API: 0.4.4-alpha.4\n";
+ report += " SDK Package Version: 0.0.3\n";
return report;
}
@@ -3,7 +3,7 @@
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
diff --git a/src/src/Databox/Model/PayloadDataModel.cs b/src/src/Databox/Model/PushData.cs
similarity index 55%
rename from src/src/Databox/Model/PayloadDataModel.cs
rename to src/src/Databox/Model/PushData.cs
index fbce727..4f11e2b 100644
--- a/src/src/Databox/Model/PayloadDataModel.cs
+++ b/src/src/Databox/Model/PushData.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -27,80 +27,73 @@
namespace Databox.Model
{
///
- /// PayloadDataModel
+ /// PushData
///
- [DataContract(Name = "PayloadDataModel")]
- public partial class PayloadDataModel : IValidatableObject
+ [DataContract(Name = "PushData")]
+ public partial class PushData : IValidatableObject
{
///
- /// Initializes a new instance of the class.
+ /// Initializes a new instance of the class.
///
- [JsonConstructorAttribute]
- protected PayloadDataModel() { }
- ///
- /// Initializes a new instance of the class.
- ///
- /// example metric name would be '$sales'.
- /// example dimension would be 'channel'.
+ /// attributes.
+ /// date.
+ /// key.
+ /// periodFrom.
+ /// periodTo.
/// unit.
- /// required if date not provided.
- /// required if date not provided.
- /// required periods not provided (required).
- public PayloadDataModel(decimal metricName = default(decimal), string dimensionName = default(string), string unit = default(string), string periodFrom = default(string), string periodTo = default(string), string date = default(string))
+ /// value.
+ public PushData(List attributes = default(List), string date = default(string), string key = default(string), string periodFrom = default(string), string periodTo = default(string), string unit = default(string), float value = default(float))
{
- // to ensure "date" is required (not null)
- if (date == null)
- {
- throw new ArgumentNullException("date is a required property for PayloadDataModel and cannot be null");
- }
+ this.Attributes = attributes;
this.Date = date;
- this.MetricName = metricName;
- this.DimensionName = dimensionName;
- this.Unit = unit;
+ this.Key = key;
this.PeriodFrom = periodFrom;
this.PeriodTo = periodTo;
+ this.Unit = unit;
+ this.Value = value;
}
///
- /// example metric name would be '$sales'
+ /// Gets or Sets Attributes
///
- /// example metric name would be '$sales'
- [DataMember(Name = "$<metric_name>", EmitDefaultValue = false)]
- public decimal MetricName { get; set; }
+ [DataMember(Name = "attributes", EmitDefaultValue = false)]
+ public List Attributes { get; set; }
///
- /// example dimension would be 'channel'
+ /// Gets or Sets Date
///
- /// example dimension would be 'channel'
- [DataMember(Name = "<dimension_name>", EmitDefaultValue = false)]
- public string DimensionName { get; set; }
+ [DataMember(Name = "date", EmitDefaultValue = false)]
+ public string Date { get; set; }
///
/// Gets or Sets Unit
///
- [DataMember(Name = "unit", EmitDefaultValue = false)]
- public string Unit { get; set; }
+ [DataMember(Name = "key", EmitDefaultValue = false)]
+ public string Key { get; set; }
///
- /// required if date not provided
+ /// Gets or Sets PeriodFrom
///
- /// required if date not provided
[DataMember(Name = "periodFrom", EmitDefaultValue = false)]
public string PeriodFrom { get; set; }
///
- /// required if date not provided
+ /// Gets or Sets PeriodTo
///
- /// required if date not provided
[DataMember(Name = "periodTo", EmitDefaultValue = false)]
public string PeriodTo { get; set; }
///
- /// required periods not provided
+ /// Gets or Sets Unit
///
- /// required periods not provided
- [DataMember(Name = "date", IsRequired = true, EmitDefaultValue = true)]
- public string Date { get; set; }
+ [DataMember(Name = "unit", EmitDefaultValue = false)]
+ public string Unit { get; set; }
+
+ ///
+ /// Gets or Sets Value
+ ///
+ [DataMember(Name = "value", EmitDefaultValue = false)]
+ public float Value { get; set; }
///
/// Returns the string presentation of the object
@@ -109,13 +102,14 @@ protected PayloadDataModel() { }
public override string ToString()
{
StringBuilder sb = new StringBuilder();
- sb.Append("class PayloadDataModel {\n");
- sb.Append(" MetricName: ").Append(MetricName).Append("\n");
- sb.Append(" DimensionName: ").Append(DimensionName).Append("\n");
- sb.Append(" Unit: ").Append(Unit).Append("\n");
+ sb.Append("class PushData {\n");
+ sb.Append(" Attributes: ").Append(Attributes).Append("\n");
+ sb.Append(" Date: ").Append(Date).Append("\n");
+ sb.Append(" Key: ").Append(Key).Append("\n");
sb.Append(" PeriodFrom: ").Append(PeriodFrom).Append("\n");
sb.Append(" PeriodTo: ").Append(PeriodTo).Append("\n");
- sb.Append(" Date: ").Append(Date).Append("\n");
+ sb.Append(" Unit: ").Append(Unit).Append("\n");
+ sb.Append(" Value: ").Append(Value).Append("\n");
sb.Append("}\n");
return sb.ToString();
}
@@ -27,80 +27,73 @@
///
- /// Gets or Sets Unit
+ /// Gets or Sets Key
///
diff --git a/src/src/Databox/Model/PayloadModel.cs b/src/src/Databox/Model/PushDataAttribute.cs
similarity index 65%
rename from src/src/Databox/Model/PayloadModel.cs
rename to src/src/Databox/Model/PushDataAttribute.cs
index bffd426..a61e94f 100644
--- a/src/src/Databox/Model/PayloadModel.cs
+++ b/src/src/Databox/Model/PushDataAttribute.cs
@@ -3,7 +3,7 @@
*
* Push API resources Open API documentation
*
- * The version of the OpenAPI document: 1.0
+ * The version of the OpenAPI document: 0.4.4-alpha.4
* Generated by: https://github.com/openapitools/openapi-generator.git
*/
@@ -27,25 +27,33 @@
namespace Databox.Model
{
///
- /// PayloadModel
+ /// PushDataAttribute
///
- [DataContract(Name = "PayloadModel")]
- public partial class PayloadModel : IValidatableObject
+ [DataContract(Name = "PushDataAttribute")]
+ public partial class PushDataAttribute : IValidatableObject
{
///
- /// Initializes a new instance of the class.
+ /// Initializes a new instance of the class.
///
- /// data.
- public PayloadModel(List data = default(List))
+ /// key.
+ /// value.
+ public PushDataAttribute(string key = default(string), string value = default(string))
{
- this.Data = data;
+ this.Key = key;
+ this.Value = value;
}
///
/// Gets or Sets Data
///
- [DataMember(Name = "data", EmitDefaultValue = false)]
- public List Data { get; set; }
+ [DataMember(Name = "key", EmitDefaultValue = false)]
+ public string Key { get; set; }
+
+ ///
+ /// Gets or Sets Value
+ ///
+ [DataMember(Name = "value", EmitDefaultValue = false)]
+ public string Value { get; set; }
///
/// Returns the string presentation of the object
@@ -54,8 +62,9 @@ public partial class PayloadModel : IValidatableObject
public override string ToString()
{
StringBuilder sb = new StringBuilder();
- sb.Append("class PayloadModel {\n");
- sb.Append(" Data: ").Append(Data).Append("\n");
+ sb.Append("class PushDataAttribute {\n");
+ sb.Append(" Key: ").Append(Key).Append("\n");
+ sb.Append(" Value: ").Append(Value).Append("\n");
sb.Append("}\n");
return sb.ToString();
}
@@ -27,25 +27,33 @@
}
///
- /// Gets or Sets Data
+ /// Gets or Sets Key
///